@@ -110,6 +110,16 @@ object GUI {
         return UncivGame.Current.worldScreen!!.selectedCiv
     }
 
+    private var keyboardAvailableCache: Boolean? = null
+    /** Tests availability of a physical keyboard */
+    val keyboardAvailable: Boolean
+        get() {
+            // defer decision if Gdx.input not yet initialized
+            if (keyboardAvailableCache == null && Gdx.input != null)
+                keyboardAvailableCache = Gdx.input.isPeripheralAvailable(Input.Peripheral.HardwareKeyboard)
+            return keyboardAvailableCache ?: false
+        }
+
 }
 
 open class UncivGame(val isConsoleMode: Boolean = false) : Game(), PlatformSpecific {
@@ -519,7 +529,7 @@ open class UncivGame(val isConsoleMode: Boolean = false) : Game(), PlatformSpeci
 
     companion object {
         //region AUTOMATICALLY GENERATED VERSION DATA - DO NOT CHANGE THIS REGION, INCLUDING THIS COMMENT
-        val VERSION = Version("4.5.5", 828)
+        val VERSION = Version("4.5.6", 829)
         //endregion
 
         lateinit var Current: UncivGame
