@@ -110,9 +110,15 @@ class MapUnit : IsPartOfGameInfoSerialization {
     var isTransported: Boolean = false
     var turnsFortified = 0
 
+    // Old, to be deprecated
+    @Deprecated("As of 4.5.3")
     var abilityUsesLeft: HashMap<String, Int> = hashMapOf()
+    @Deprecated("As of 4.5.3")
     var maxAbilityUses: HashMap<String, Int> = hashMapOf()
 
+    // New - track only *how many have been used*, derive max from uniques, left = max - used
+    var abilityToTimesUsed: HashMap<String, Int> = hashMapOf()
+
     var religion: String? = null
     var religiousStrengthLost = 0
 
@@ -174,6 +180,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
         toReturn.isTransported = isTransported
         toReturn.abilityUsesLeft.putAll(abilityUsesLeft)
         toReturn.maxAbilityUses.putAll(maxAbilityUses)
+        toReturn.abilityToTimesUsed.putAll(abilityToTimesUsed)
         toReturn.religion = religion
         toReturn.religiousStrengthLost = religiousStrengthLost
         toReturn.movementMemories = movementMemories.copy()
@@ -815,12 +822,12 @@ class MapUnit : IsPartOfGameInfoSerialization {
         return civ.gameInfo.religions[religion]!!.getReligionDisplayName()
     }
 
-    fun religiousActionsUnitCanDo(): Sequence<String> {
+    fun limitedActionsUnitCanDo(): Sequence<String> {
         return getMatchingUniques(UniqueType.CanActionSeveralTimes)
             .map { it.params[0] }
     }
 
-    fun canDoReligiousAction(action: String): Boolean {
+    fun canDoLimitedAction(action: String): Boolean {
         return getMatchingUniques(UniqueType.CanActionSeveralTimes).any { it.params[0] == action }
     }
 
@@ -833,7 +840,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
     }
 
     fun setupAbilityUses(buildCity: City? = null) {
-        for (action in religiousActionsUnitCanDo()) {
+        for (action in limitedActionsUnitCanDo()) {
             val baseAmount = getBaseMaxActionUses(action)
             val additional =
                 if (buildCity == null) 0
