@@ -25,6 +25,7 @@ import com.unciv.ui.components.FontFamilyData
 import com.unciv.ui.components.Fonts
 import com.unciv.ui.components.UncivSlider
 import com.unciv.ui.components.UncivTooltip.Companion.addTooltip
+import com.unciv.ui.components.extensions.center
 import com.unciv.ui.components.extensions.disable
 import com.unciv.ui.components.extensions.keyShortcuts
 import com.unciv.ui.components.extensions.onActivation
@@ -35,6 +36,8 @@ import com.unciv.ui.components.extensions.toCheckBox
 import com.unciv.ui.components.extensions.toLabel
 import com.unciv.ui.components.extensions.toTextButton
 import com.unciv.ui.components.extensions.withoutItem
+import com.unciv.utils.Display
+import com.unciv.utils.ScreenOrientation
 import com.unciv.utils.concurrency.Concurrency
 import com.unciv.utils.concurrency.launchOnGLThread
 import kotlinx.coroutines.CoroutineScope
@@ -54,21 +57,16 @@ fun advancedTab(
 
     addAutosaveTurnsSelectBox(this, settings)
 
-    if (UncivGame.Current.hasDisplayCutout())
-        optionsPopup.addCheckbox(this, "Enable display cutout (requires restart)", settings.androidCutout) {
-            settings.androidCutout = it
-        }
+    if (Display.hasOrientation()) {
+        addOrientationSelectBox(this, optionsPopup)
+    }
+
+    if (Display.hasCutout()) {
+        addCutoutCheckbox(this, optionsPopup)
+    }
 
     addMaxZoomSlider(this, settings)
 
-    if (Gdx.app.type == Application.ApplicationType.Android) {
-        optionsPopup.addCheckbox(this, "Enable portrait orientation", settings.allowAndroidPortrait) {
-            settings.allowAndroidPortrait = it
-            // Note the following might close the options screen indirectly and delayed
-            UncivGame.Current.allowPortrait(it)
-        }
-    }
-
     addFontFamilySelect(this, settings, optionsPopup.selectBoxMinWidth, onFontChange)
 
     addFontSizeMultiplier(this, settings, onFontChange)
@@ -80,6 +78,31 @@ fun advancedTab(
     addEasterEggsCheckBox(this, settings)
 }
 
+private fun addCutoutCheckbox(table: Table, optionsPopup: OptionsPopup) {
+    optionsPopup.addCheckbox(table, "Enable display cutout (requires restart)", optionsPopup.settings.androidCutout)
+    {
+        optionsPopup.settings.androidCutout = it
+    }
+}
+
+private fun addOrientationSelectBox(table: Table, optionsPopup: OptionsPopup) {
+
+    val settings = optionsPopup.settings
+
+    table.add("Screen orientation".toLabel()).left().fillX()
+
+    val selectBox = SelectBox<ScreenOrientation>(table.skin)
+    selectBox.items = Array(ScreenOrientation.values())
+    selectBox.selected = settings.displayOrientation
+    selectBox.onChange {
+        val orientation = selectBox.selected
+        settings.displayOrientation = orientation
+        Display.setOrientation(orientation)
+    }
+
+    table.add(selectBox).minWidth(optionsPopup.selectBoxMinWidth).pad(10f).row()
+}
+
 private fun addAutosaveTurnsSelectBox(table: Table, settings: GameSettings) {
     table.add("Turns between autosaves".toLabel()).left().fillX()
 
